@@ -291,24 +291,51 @@ ta_export_signals = {
         "class": KSTIndicator,
         "module": "ta.trend",
         "function_names": "kst",
-        "parameters": {"roc1": 10, "roc2": 15, "roc3": 20, "roc4": 30, "window1": 10, "window2": 10, "window3": 10,
-                       "window4": 15, "nsig": 9},
+        "parameters": {
+            "roc1": 10,
+            "roc2": 15,
+            "roc3": 20,
+            "roc4": 30,
+            "window1": 10,
+            "window2": 10,
+            "window3": 10,
+            "window4": 15,
+            "nsig": 9,
+        },
         "series": ["close"],
     },
     "kst_diff": {
         "class": KSTIndicator,
         "module": "ta.trend",
         "function_names": "kst_diff",
-        "parameters": {"roc1": 10, "roc2": 15, "roc3": 20, "roc4": 30, "window1": 10, "window2": 10, "window3": 10,
-                       "window4": 15, "nsig": 9},
+        "parameters": {
+            "roc1": 10,
+            "roc2": 15,
+            "roc3": 20,
+            "roc4": 30,
+            "window1": 10,
+            "window2": 10,
+            "window3": 10,
+            "window4": 15,
+            "nsig": 9,
+        },
         "series": ["close"],
     },
     "kst_sig": {
         "class": KSTIndicator,
         "module": "ta.trend",
         "function_names": "kst_sig",
-        "parameters": {"roc1": 10, "roc2": 15, "roc3": 20, "roc4": 30, "window1": 10, "window2": 10, "window3": 10,
-                       "window4": 15, "nsig": 9},
+        "parameters": {
+            "roc1": 10,
+            "roc2": 15,
+            "roc3": 20,
+            "roc4": 30,
+            "window1": 10,
+            "window2": 10,
+            "window3": 10,
+            "window4": 15,
+            "nsig": 9,
+        },
         "series": ["close"],
     },
     "macd": {
